@@ -20,8 +20,7 @@ class MxitGA(object):
 			return
 		try:
 			visitor = Visitor()
-			visitor.ip_address = request.headers['X-Forwarded-For'].split(',')[-1].strip()
-			print(visitor.ip_address)
+			visitor.ip_address = request.headers['X-Forwarded-For'].split(',')[0].strip()
 			#TODO: Persist sessions.
 			session = Session()
 			page = Page(request.path)
